@@ -37,14 +37,18 @@ def run(
     # If a source is provided, limit the list
     if source:
         file_list = [f for f in file_list if source.lower() in f.lower()]
+        if len(file_list) == 0:
+            logger.debug(f"No source '{source}' found")
 
     # Make the download directory, if it doesn't already exist.
     if not download_dir.exists():
         download_dir.mkdir(parents=True)
 
     # Download all the files.
-    for f in file_list:
-        logger.debug(f"Download {f} to {download_dir}")
+    for i, f in enumerate(sorted(file_list)):
+        logger.debug(
+            f"Download {f} to {download_dir} as file {i+1:02d} of {len(file_list):02d}"
+        )
         c.download_file(BLN_PROJECT_ID, f, output_dir=download_dir)
 
 
