@@ -8,7 +8,7 @@ class Transformer(BaseTransformer):
     fields = dict(
         company="employer",
         location="city",
-        date="notice_date",
+        notice_date="notice_date",
         jobs="number_of_employees_affected",
     )
     date_format = "%b %d, %Y"
