@@ -8,7 +8,7 @@ class Transformer(BaseTransformer):
     fields = dict(
         company="Company",
         location="Location",
-        notice_date="Date",
+        notice_date="Date Received",
         jobs="Employees Affected",
     )
     date_format = "%m/%d/%Y"
